@@ -1,4 +1,4 @@
-from sql2gee.sql2gee import SQL2GEE
+from .sql2gee import SQL2GEE
 from pkg_resources import get_distribution
 
 __version__ = get_distribution('sql2gee').version
\ No newline at end of file
